@@ -27,6 +27,7 @@ class TagValues(str, enum.Enum):
     DIRECTION_SENSOR = "Direction Sensor"
     EKF_ALGORITHM = "EKF Algorithm"
     FOV_CONSTRAINT = "FOV Constraint"
+    FUEL_RESERVOIR = "Fuel Reservoir"
     GPS_ALGORITHM = "GPS Algorithm"
     GROUND_TARGET = "Ground Target"
     GROUP_CONDITION = "Group Condition"
@@ -52,6 +53,9 @@ class TagValues(str, enum.Enum):
     SOLAR_CELL = "Solar Cell"
     SOLAR_PANEL = "Solar Panel"
     SPACE_TARGET = "Space Target"
+    SPHERICAL_FUEL_TANK = "Spherical Fuel Tank"
+    SPHEROCYLINDER_FUEL_TANK = "Spherocylinder Fuel Tank"
+    STATIC_THRUST_CONTROL_ALGORITHM = "Static Thrust Control Algorithm"
     SUBSYSTEM = "Subsystem"
     SURFACE = "Surface"
     SURFACE_MATERIAL = "Surface Material"
@@ -61,6 +65,7 @@ class TagValues(str, enum.Enum):
     TEMP_CONTROLLER_STATE = "Temp Controller State"
     THERMAL_INTERFACE = "Thermal Interface"
     THERMAL_INTERFACE_MATERIAL = "Thermal Interface Material"
+    THRUSTER = "Thruster"
     TOPOLOGY = "Topology"
     TRIAD_ALGORITHM = "Triad Algorithm"
     VECTOR_SENSOR = "Vector Sensor"
